@@ -1,3 +1,6 @@
 from openfisca_core.model_api import *
 from openfisca_us.entities import *
 from openfisca_us.tools.general import *
+from pathlib import Path
+
+REPO = Path(__file__).parent
